@@ -280,6 +280,29 @@ class BrailleGenerator(generator.Generator):
         result.reverse()
         return result
 
+    def _generateFocusedItem(self, obj, **args):
+        result = []
+        role = args.get('role', obj.getRole())
+        if role != pyatspi.ROLE_LIST:
+            return result
+
+        try:
+            s = obj.querySelection()
+        except NotImplementedError:
+            isFocused = \
+                lambda x: x and x.getState().contains(pyatspi.STATE_FOCUSED)
+            items = pyatspi.utils.findAllDescendants(obj, isFocused)
+        else:
+            items = [s.getSelectedChild(i) for i in range(s.nSelectedChildren)]
+            if not items and obj.childCount:
+                items.append(obj[0])
+
+        items = list(map(self._generateName, items))
+        for item in items:
+            result.extend(item)
+
+        return result
+
     #####################################################################
     #                                                                   #
     # Unfortunate hacks.                                                #
