@@ -30,23 +30,19 @@ import Queue
 import threading
 import time
 
-import orca # Deal with this during final Python 3 conversion
-
-from . import braille
 from . import debug
 from . import input_event
 from . import orca_state
+from . import script_manager
 from . import settings
-from . import speech
 
 from .orca_i18n import _
 
-_scriptManager = None
+_scriptManager = script_manager.getManager()
 
 class EventManager:
 
     def __init__(self):
-
         debug.println(debug.LEVEL_FINEST, 'INFO: Initializing event manager')
         self._scriptListenerCounts = {}
         self.registry = pyatspi.Registry
@@ -62,14 +58,6 @@ class EventManager:
         """Called when this presentation manager is activated."""
 
         debug.println(debug.LEVEL_FINEST, 'INFO: Activating event manager')
-
-        global _scriptManager
-        _scriptManager = getattr(orca, '_scriptManager')
-
-        # Tell BrlTTY which commands we care about.
-        #
-        braille.setupKeyRanges(list(orca_state.activeScript.brailleBindings.keys()))
-
         self._registerListener("window:activate")
         self._registerListener("window:deactivate")
         self._registerListener("object:children-changed")
@@ -249,13 +237,9 @@ class EventManager:
                     # speak and braille to tell the user that no component
                     # has keyboard focus.
                     #
-                    message = _("No focus")
-                    if settings.brailleVerbosityLevel == \
-                            settings.VERBOSITY_LEVEL_VERBOSE:
-                        braille.displayMessage(message)
-                    if settings.speechVerbosityLevel == \
-                            settings.VERBOSITY_LEVEL_VERBOSE:
-                        speech.speak(message)
+                    fullMessage = _("No focus")
+                    defaultScript = _scriptManager.getDefaultScript()
+                    defaultScript.presentMessage(fullMessage, '')
                     self.noFocusTimestamp = orca_state.noFocusTimestamp
                 self._gidleId = 0
                 rerun = False # destroy and don't call again
@@ -504,10 +488,6 @@ class EventManager:
             try:
                 if event.source == self.registry.getDesktop(0):
                     _scriptManager.reclaimScripts()
-                    if settings.debugMemoryUsage:
-                        orca.cleanupGarbage()
-                    if not event.source.childCount:
-                        orca.shutdown()
                     return
             except (LookupError, RuntimeError):
                 # If we got this error here, we'll get it again when we
@@ -533,7 +513,7 @@ class EventManager:
             debug.println(debug.LEVEL_WARNING,
                           "Error while processing event: %s" % eType)
             if eType.startswith("window:deactivate"):
-                orca.setLocusOfFocus(event, None)
+                orca_state.locusOfFocus = None
                 orca_state.activeWindow = None
             return
         except:
@@ -543,7 +523,7 @@ class EventManager:
         if state and state.contains(pyatspi.STATE_DEFUNCT):
             debug.println(debug.LEVEL_FINEST, "IGNORING DEFUNCT OBJECT")
             if eType.startswith("window:deactivate"):
-                orca.setLocusOfFocus(event, None)
+                orca_state.locusOfFocus = None
                 orca_state.activeWindow = None
             return
 
@@ -603,3 +583,8 @@ class EventManager:
             return True
         else:
             return False
+
+_manager = EventManager()
+
+def getManager():
+    return _manager
