@@ -636,12 +636,6 @@ synchronousToolkits     = ['VCL']
 #
 debugEventQueue         = False
 
-# If True, we collect information regarding memory usage and provide
-# keystrokes to dump the usage information to the console:
-# Orca+Ctrl+F8 for brief, Orca+Shift+Ctrl+F8 for detailed.
-#
-debugMemoryUsage        = False
-
 # The timeout value (in seconds) and callback used to determine if
 # Orca has hung or not.  The only setting one should muck with here is
 # the timeoutTime unless you want to create a custom callback handler
@@ -681,9 +675,8 @@ chatRoomHistories = False
 # Allow for the customization of key bindings.
 #
 def overrideKeyBindings(script, keyBindings):
-    import orca # Deal with this during final Python 3 conversion
-    _settingsManager = getattr(orca, '_settingsManager')
-
+    from . import settings_manager
+    _settingsManager = settings_manager.getManager()
     return _settingsManager.overrideKeyBindings(script, keyBindings)
 
 # Allow for user customization of pronunciations.
